pub fn f2_loop_fairness() -> LoopFairnessGateExpand description
F2: a 100-iteration loop gets one quantum, then yields to an already-waiting peer.
pub fn f2_loop_fairness() -> LoopFairnessGateF2: a 100-iteration loop gets one quantum, then yields to an already-waiting peer.