pub struct ContextSectionRegistry { /* private fields */ }Expand description
Registry for prompt/context sections and their lifecycle policy.
Implementations
Sourceimpl ContextSectionRegistry
impl ContextSectionRegistry
pub fn new() -> Self
Sourcepub fn default_agent_sections() -> Self
pub fn default_agent_sections() -> Self
Baseline sections that match DeepStrike’s current 5-partition context.
pub fn upsert(&mut self, section: ContextSection)
pub fn get(&self, id: &str) -> Option<&ContextSection>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn sections(&self) -> Vec<&ContextSection>
pub fn plan(&self) -> ContextSectionPlan
Sourcepub fn pin(&mut self, id: &str) -> bool
pub fn pin(&mut self, id: &str) -> bool
Pin a section so its partition is exempt from GC compression. Returns true if the section was found.
Sourcepub fn unpin(&mut self, id: &str) -> bool
pub fn unpin(&mut self, id: &str) -> bool
Unpin a section, allowing its partition to be compressed again. Returns true if the section was found.
Sourcepub fn is_partition_pinned(&self, partition: ContextSectionPartition) -> bool
pub fn is_partition_pinned(&self, partition: ContextSectionPartition) -> bool
Returns true if any enabled section mapped to partition is pinned.
Sourcepub fn invalidate(&mut self, event: SectionInvalidation) -> Vec<CompactString>
pub fn invalidate(&mut self, event: SectionInvalidation) -> Vec<CompactString>
Mark sections invalidated by an event as disabled and return their ids.