pub struct JudgeMatch {
pub left: String,
pub right: String,
}Expand description
A pairwise judge assignment carried to the SDK on a tournament judge’s WorkflowSpawnInfo:
the two entrant agent ids whose produced outputs are to be compared. The SDK maps each id back
to that entrant’s candidate and asks the judge which is better.
Fields
left: Stringright: StringTrait Implementations
Sourceimpl Clone for JudgeMatch
impl Clone for JudgeMatch
Sourcefn clone(&self) -> JudgeMatch
fn clone(&self) -> JudgeMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JudgeMatch
impl Debug for JudgeMatch
Sourceimpl<'de> Deserialize<'de> for JudgeMatch
impl<'de> Deserialize<'de> for JudgeMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for JudgeMatch
Sourceimpl PartialEq for JudgeMatch
impl PartialEq for JudgeMatch
Sourcefn eq(&self, other: &JudgeMatch) -> bool
fn eq(&self, other: &JudgeMatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for JudgeMatch
impl Serialize for JudgeMatch
impl StructuralPartialEq for JudgeMatch