pub struct ClassifyBranch {
pub label: String,
pub nodes: Vec<usize>,
}Expand description
One branch of a NodeKind::Classify node: a label and the node indices to enable when the
classifier’s result selects that label. The other branches’ nodes are pruned (failed) so they
never run — this is how a classify node yields conditional edges in an otherwise static DAG.
Fields
label: Stringnodes: Vec<usize>Trait Implementations
Sourceimpl Clone for ClassifyBranch
impl Clone for ClassifyBranch
Sourcefn clone(&self) -> ClassifyBranch
fn clone(&self) -> ClassifyBranch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassifyBranch
impl Debug for ClassifyBranch
Sourceimpl<'de> Deserialize<'de> for ClassifyBranch
impl<'de> Deserialize<'de> for ClassifyBranch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ClassifyBranch
Sourceimpl PartialEq for ClassifyBranch
impl PartialEq for ClassifyBranch
Sourcefn eq(&self, other: &ClassifyBranch) -> bool
fn eq(&self, other: &ClassifyBranch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ClassifyBranch
impl Serialize for ClassifyBranch
impl StructuralPartialEq for ClassifyBranch