pub struct BudgetSlice {
pub max_turns: u32,
pub max_total_tokens: u64,
pub max_wall_ms: Option<u64>,
}Expand description
The budget a task is granted for the next run step. M1’s schedule() returns one of these.
Fields
max_turns: u32max_total_tokens: u64max_wall_ms: Option<u64>Trait Implementations
Sourceimpl Clone for BudgetSlice
impl Clone for BudgetSlice
Sourcefn clone(&self) -> BudgetSlice
fn clone(&self) -> BudgetSlice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BudgetSlice
Sourceimpl Debug for BudgetSlice
impl Debug for BudgetSlice
impl Eq for BudgetSlice
Sourceimpl PartialEq for BudgetSlice
impl PartialEq for BudgetSlice
Sourcefn eq(&self, other: &BudgetSlice) -> bool
fn eq(&self, other: &BudgetSlice) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BudgetSlice